@@ -21,7 +21,7 @@ class SecretManager(object):
             self.client = secretmanager.SecretManagerServiceClient.from_service_account_file(service_accout_json_file_path)
 
         # Build the parent name from the project.
-        self.project_path = self.client.project_path(project_id)
+        self.project_path = "projects/{}".format(project_id)
 
     def create_secret(self, secret_id: str, value=None, regions=None, labels=None):
         """
@@ -39,11 +39,16 @@ class SecretManager(object):
         if isinstance(regions, list):
             replicas = [{'location': region} for region in regions]
 
-        response = self.client.create_secret(self.project_path, secret_id, {
-            'replication': {
-                'user_managed': {'replicas': replicas},
+        response = self.client.create_secret(
+            request={
+            'parent': self.project_path,
+            'secret_id': secret_id,
+            'secret': {'replication': {
+                'user_managed':
+                    {'replicas': replicas},
             },
-            'labels': labels
+            'labels': labels},
+
         })
 
         if value is None:
@@ -65,7 +70,7 @@ class SecretManager(object):
         parent = self.client.secret_path(self.project_id, secret_id)
 
         # Add the secret version.
-        response = self.client.add_secret_version(parent, {'data': payload})
+        response = self.client.add_secret_version(request={"parent": parent, "payload": {'data': payload}})
         return response.name
 
     def access_secret_version(self, secret_id, version_id):
@@ -77,9 +82,9 @@ class SecretManager(object):
         :return: secret data (str)  !!!WARNING: Do not print the secret in a production environment!!!
         """
         # Build the resource name of the secret version.
-        name = self.client.secret_version_path(self.project_id, secret_id, version_id)
+        name = "projects/{}/secrets/{}/versions/{}".format(self.project_id, secret_id, version_id)
         # Access the secret version.
-        response = self.client.access_secret_version(name)
+        response = self.client.access_secret_version(request={"name": name})
         return response.payload.data.decode('UTF-8')
 
     def list_secret_versions(self, secret_id: str):
@@ -89,8 +94,8 @@ class SecretManager(object):
         :param secret_id: str, required
         :return: list of all versions of your secret
         """
-        parent = self.client.secret_path(self.project_id, secret_id)
-        return [version for version in self.client.list_secret_versions(parent)]
+        name = "projects/{}/secrets/{}".format(self.project_id, secret_id)
+        return [version for version in self.client.list_secret_versions(request={"parent": name})]
 
     def list_secrets(self):
         """
@@ -99,8 +104,7 @@ class SecretManager(object):
         :return: list of all secret names
         """
         # Build the resource name of the parent project.
-        parent = self.client.project_path(self.project_id)
-        return [secret for secret in self.client.list_secrets(parent)]
+        return [secret for secret in self.client.list_secrets({"parent": self.project_path})]
 
     def get_secret(self, secret_id):
         """
@@ -115,7 +119,7 @@ class SecretManager(object):
         name = self.client.secret_path(self.project_id, secret_id)
 
         # Get the secret.
-        return self.client.get_secret(name)
+        return self.client.get_secret(request={"name": name})
 
     def delete_secret(self, secret_id):
         """
@@ -127,28 +131,50 @@ class SecretManager(object):
         name = self.client.secret_path(self.project_id, secret_id)
 
         # Delete the secret.
-        self.client.delete_secret(name)
+        self.client.delete_secret(request={"name": name})
+
+
+    def delete_secret_version(self, secret_id, secret_version):
+
+        '''
+
+        :param secret_id: str, required
+        :param secret_version: str, required
+        :return:
+        '''
+
+        name = "projects/{}/secrets/{}/versions/{}".format(self.project_id, secret_id, secret_version)
+        self.client.destroy_secret_version(request={"name": name})
+
+
+
 
 if __name__ == '__main__':
 
+
     # First, enable the secret manager API  on GCP console
 
     # Init secretmanager object with your the default credential from your environment:
-    #secretmanager = SecretManager("v135-5683-playground-goppold")
+    secretmanager = SecretManager("playground-josef")
     # Init secretmanager object with your a service account json file - specify the path to your file:
-    secretmanager = SecretManager("v135-5683-playground-goppold", "test.json")
-
-    # Create a secret value
+    #secretmanager = SecretManager("v135-5683-playground-goppold", "test.json")
+    #secretmanager.update_secret_version('test', 'new value')
+    
+    # Create a secret 
     secret_name = secretmanager.create_secret("my-secret")
     print(secret_name)
+    
+    
     # Create a secret with value
     secret_version_name = secretmanager.create_secret("my-secret-with-value", "This is my secret value")
     print(secret_version_name)
+    
     # By default: regions=["europe-west4"] and labels=None. Please specify this params of you need to.
 
     # Add a secret value to a existing secret:
     secret_version_name_1 = secretmanager.add_secret_version("my-secret", "This is another secret value")
     print(secret_version_name_1)
+    
     secret_version_name_2 = secretmanager.add_secret_version("my-secret", "This is a new verison of my secret value")
     print(secret_version_name_2)
 
