@@ -13,11 +13,11 @@ class Redis(object):
         redis_client = redis.Redis(host=host, port=port, password=password)
         return redis_client
 
-    def __init__(self, host, port, password, exp=60*15):
+    def __init__(self, host: str, port: str, password: str, exp_s: int):
         self.host = host
         self.port = port
         self.password = password
-        self.exp = exp
+        self.exp = exp_s
         self.redis_client = self.create_redis_client(self.host, self.port, self.password)
 
     def set_redis(self, set_key, set_value):
